OrmGenerator class
Generate <Model>.g.dart from an abstract Model class.
Constructors
- OrmGenerator({bool? autoSnakeCaseNames})
Properties
- autoSnakeCaseNames → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inPackage → String?
-
Annotation package for
TypeChecker.typeNamed.finalinherited - inSdk → bool?
-
Annotation package type for
TypeChecker.typeNamed.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- throwOnUnresolved → bool
-
finalinherited
- typeChecker → TypeChecker
-
no setterinherited
Methods
-
buildOrmLibrary(
AssetId inputId, OrmBuildContext ctx) → Library -
buildQueryClass(
OrmBuildContext ctx) → Class - Generate "Model"Query class
-
buildValuesClass(
OrmBuildContext ctx) → Class - Generate "Model"QueryValues class
-
buildWhereClass(
OrmBuildContext ctx) → Class - Generate "Model"QueryWhere class
-
generate(
LibraryReader library, BuildStep buildStep) → FutureOr< String> -
Generates Dart code for an input Dart library.
inherited
-
generateForAnnotatedDirective(
ElementDirective directive, ConstantReader annotation, BuildStep buildStep) → dynamic -
Implement to return source code to generate for
directive:inherited -
generateForAnnotatedElement(
Element element, ConstantReader annotation, BuildStep buildStep) → Future< String> -
Implement to return source code to generate for
element. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited