-
baseElement
→ FieldElementImpl
-
The non-
SubstitutedElementImpl version of this element.
no setterinherited
-
children
→ List<Element>
-
The children of this element.
no setterinherited
-
children2
→ List<Element>
-
The children of this element.
no setterinherited
-
constantInitializer
→ ExpressionImpl?
-
The constant initializer for this constant variable, or the default
value for this formal parameter.
no setterinherited
-
constantInitializer2
→ ConstantInitializerImpl?
-
no setterinherited
-
displayName
→ String
-
The display name of this element, or an empty string if the element does
not have a name.
no setter
-
The content of the documentation comment (including delimiters) for this
element.
no setterinherited
-
enclosingElement
→ InstanceElementImpl
-
The element that either physically or logically encloses this element.
no setterinherited
-
enclosingElement2
→ InstanceElement
-
The element that either physically or logically encloses this element.
no setterinherited
-
evaluationResult
↔ Constant?
-
The result of evaluating
constantInitializer2.
getter/setter pairinherited
-
fieldName
→ String
-
final
-
firstFragment
→ FieldFragmentImpl
-
The first fragment in the chain of fragments that are merged to make this
element.
no setterinherited
-
firstFragmentLocation
→ FirstFragmentLocation
-
The location of
firstFragment, without recording opaque requirement.
no setterinherited
-
fragments
→ List<FieldFragmentImpl>
-
The fragments this element consists of.
no setterinherited
-
getter
↔ GetterElementImpl?
-
The getter associated with this variable.
getter/setter pairinherited
-
getter2
→ GetterElementImpl?
-
The getter associated with this variable.
no setterinherited
-
hasEnclosingTypeParameterReference
↔ bool
-
Whether the type of this fragment references a type parameter of the
enclosing element. This includes not only explicitly specified type
annotations, but also inferred types.
getter/setter pairinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasImplicitType
→ bool
-
Whether the variable element did not have an explicit type specified
for it.
no setterinherited
-
hasInitializer
→ bool
-
Whether any fragment of this variable has an initializer at declaration.
no setterinherited
-
id
→ int
-
finalinherited
-
isAbstract
→ bool
-
Whether the field is abstract.
no setterinherited
-
isConst
→ bool
-
Whether the variable was declared with the 'const' modifier.
no setterinherited
-
isConstantEvaluated
→ bool
-
Return whether this constant is evaluated.
no setterinherited
-
isCovariant
→ bool
-
Whether the field was explicitly marked as being covariant.
no setterinherited
-
isEnumConstant
→ bool
-
Whether the element is an enum constant.
no setterinherited
-
isEnumValues
→ bool
-
no setterinherited
-
isExternal
→ bool
-
Whether the field was explicitly marked as being external.
no setterinherited
-
isFinal
→ bool
-
Whether the variable was declared with the 'final' modifier.
no setterinherited
-
isLate
→ bool
-
Whether the variable uses late evaluation semantics.
no setterinherited
-
isPrivate
→ bool
-
Whether this element is private.
no setterinherited
-
isPromotable
→ bool
-
Whether the field can be type promoted.
no setterinherited
-
isPublic
→ bool
-
Whether this element is public.
no setterinherited
-
isStatic
→ bool
-
Whether the element is a static variable, as per section 8 of the Dart
Language Specification:
no setterinherited
-
isSynthetic
→ bool
-
Whether this element is synthetic.
no setterinherited
-
isSyntheticEnumField
→ bool
-
Return
true if this element is a synthetic enum field.
no setterinherited
-
kind
→ ElementKind
-
The kind of this element.
no setterinherited
-
lastFragment
→ FieldFragmentImpl
-
no setterinherited
-
library
→ LibraryElementImpl
-
Library that contains this element.
no setterinherited
-
library2
→ LibraryElementImpl
-
Library that contains this element.
no setterinherited
-
libraryFragment
→ LibraryFragmentImpl?
-
The library fragment with the first fragment of this constant.
no setterinherited
-
lookupName
→ String?
-
The name to use for lookup in maps.
no setterinherited
-
metadata
→ MetadataImpl
-
The metadata associated with the element.
no setterinherited
-
metadata2
→ MetadataImpl
-
The metadata associated with the element or fragment.
no setterinherited
-
name
→ String?
-
The name of this element.
no setterinherited
-
name3
→ String?
-
The name of this element.
no setterinherited
-
nonSynthetic
→ Element
-
The non-synthetic element that caused this element to be created.
no setterinherited
-
nonSynthetic2
→ Element
-
The non-synthetic element that caused this element to be created.
no setterinherited
-
originalField
→ FieldElement
-
final
-
originalFieldName
→ String
-
no setter
-
reference
→ Reference
-
finalinherited
-
relationship
→ RelationshipReader
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
session
→ AnalysisSession?
-
The analysis session in which this element is defined.
no setterinherited
-
setter
↔ SetterElementImpl?
-
The setter associated with this variable.
getter/setter pairinherited
-
setter2
→ SetterElementImpl?
-
The setter associated with this variable.
no setterinherited
-
shouldUseTypeForInitializerInference
↔ bool
-
getter/setter pairinherited
-
sinceSdkVersion
→ Version?
-
The version where the associated SDK API was added.
no setterinherited
-
type
↔ TypeImpl
-
The declared type of this variable.
getter/setter pairinherited