lookupName property

  1. @override
  2. @trackedIndirectly
String? get lookupName
inherited

The name to use for lookup in maps.

It is usually the same as name, with a few special cases.

Just like name, it can be null if the element does not have a name, for example an unnamed extension, or because of parser recovery.

For a SetterElement the result has = at the end.

For an unary operator - the result is unary-. For a binary operator - the result is just -.

Implementation

@override
@trackedIndirectly
String? get lookupName {
  return name;
}